@@ -1,3 +1,5 @@
+from typing import Any
+
 from .interface import Interface
 
 
@@ -5,7 +7,7 @@ class ICalibrate(Interface):
     """The module can calibrate a device."""
     __module__ = 'pyobs.interfaces'
 
-    def calibrate(self, *args, **kwargs):
+    def calibrate(self, **kwargs: Any) -> None:
         """Calibrate the device."""
         raise NotImplementedError
 
