@@ -1,3 +1,5 @@
+from typing import Any, Dict
+
 from .interface import Interface
 
 
@@ -5,7 +7,7 @@ class ITemperatures(Interface):
     """The module can return temperatures measured on some device."""
     __module__ = 'pyobs.interfaces'
 
-    def get_temperatures(self, *args, **kwargs) -> dict:
+    def get_temperatures(self, **kwargs: Any) -> Dict[str, float]:
         """Returns all temperatures measured by this module.
 
         Returns:
