@@ -1,7 +1,8 @@
 import logging
-import typing
+from typing import Union, Dict, Any
 
-from pyobs.interfaces import ITelescope, IRunnable
+from pyobs.interfaces import IRunnable
+from pyobs.interfaces.proxies import ITelescopeProxy
 from pyobs.modules import Module
 from pyobs.object import get_object
 from pyobs.modules import timeout
@@ -14,27 +15,27 @@ class FlatFieldPointing(Module, IRunnable):
     """Module for pointing a telescope."""
     __module__ = 'pyobs.modules.flatfield'
 
-    def __init__(self, telescope: typing.Union[str, ITelescope], pointing: typing.Union[dict, SkyFlatsBasePointing],
-                 *args, **kwargs):
+    def __init__(self, telescope: Union[str, ITelescopeProxy],
+                 pointing: Union[Dict[str, Any], SkyFlatsBasePointing], **kwargs: Any):
         """Initialize a new flat field pointing.
 
         Args:
             telescope: Telescope to point
             pointing: Pointing for calculating coordinates.
         """
-        Module.__init__(self, *args, **kwargs)
+        Module.__init__(self, **kwargs)
 
         # store telescope and pointing
         self._telescope = telescope
         self._pointing = pointing
 
     @timeout(60)
-    def run(self, *args, **kwargs):
+    def run(self, **kwargs: Any) -> None:
         """Move telescope to pointing."""
 
         # get telescope
         log.info('Getting proxy for telescope...')
-        telescope: ITelescope = self.proxy(self._telescope, ITelescope)
+        telescope: ITelescopeProxy = self.proxy(self._telescope, ITelescopeProxy)
 
         # pointing
         pointing = get_object(self._pointing, SkyFlatsBasePointing, observer=self.observer)
@@ -43,7 +44,7 @@ class FlatFieldPointing(Module, IRunnable):
         pointing(telescope).wait()
         log.info('Finished pointing telescope.')
 
-    def abort(self, *args, **kwargs):
+    def abort(self, **kwargs: Any) -> None:
         """Abort current actions."""
         pass
 
