@@ -1,6 +1,6 @@
 import logging
 import threading
-import typing
+from typing import Dict, Any
 
 from pyobs.object import get_object
 from pyobs.robotic.scripts import Script
@@ -12,18 +12,18 @@ log = logging.getLogger(__name__)
 class LcoScript(Script):
     """Auto SCRIPT script for LCO configs."""
 
-    def __init__(self, scripts: typing.Dict[str, Script], *args, ** kwargs):
+    def __init__(self, scripts: Dict[str, Script], **kwargs: Any):
         """Initialize a new LCO auto focus script.
 
         Args:
             scripts: External scripts to run
         """
-        Script.__init__(self, *args, **kwargs)
+        Script.__init__(self, **kwargs)
 
         # store
         self.scripts = scripts
 
-    def _get_config_script(self, config: dict) -> Script:
+    def _get_config_script(self, config: Dict[str, Any]) -> Script:
         """Get config script for given configuration.
 
         Args:
@@ -42,7 +42,7 @@ class LcoScript(Script):
             raise ValueError('No script found for script type "%s".' % config_type)
 
         # create script handler
-        return get_object(self.scripts[config_type],
+        return get_object(self.scripts[config_type], Script,
                           configuration=config, task_archive=self.task_archive, comm=self.comm, observer=self.observer)
 
     def can_run(self) -> bool:
@@ -56,10 +56,9 @@ class LcoScript(Script):
         runner = self._get_config_script(self.configuration)
 
         # if any runner can run, we proceed
-        if runner.can_run():
-            return True
+        return runner.can_run()
 
-    def run(self, abort_event: threading.Event):
+    def run(self, abort_event: threading.Event) -> None:
         """Run script.
 
         Args:
