@@ -70,11 +70,14 @@ def cast_response_to_real(response: Any, signature: Signature) -> Any:
     if response is None or annotation == Parameter.empty or annotation == Any:
         # no response or no annotation at all or Any
         return response
-    elif hasattr(annotation, '__origin__') and annotation.__origin__ == tuple or isinstance(annotation, tuple):
+    elif (hasattr(annotation, '__origin__') and annotation.__origin__ == tuple) or isinstance(annotation, tuple):
         # parse tuple
         # return tuple([None if res is None else annot(res) for res, annot in zip(response, annotation)])
         return response
-    elif hasattr(annotation, '__origin__') and annotation.__origin__ in [dict]:
+    elif (hasattr(annotation, '__origin__') and annotation.__origin__ == list) or isinstance(annotation, list):
+        # parse list
+        return response
+    elif (hasattr(annotation, '__origin__') and annotation.__origin__ == dict) or isinstance(annotation, dict):
         # just return it
         return response
     else:
